# HTTPSecuritySettings

Configuration of an HTTP Application's security model.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**csp** | **dict, none_type** |  | [optional] 
**cors** | **dict, none_type** |  | [optional] 
**hsts** | **dict, none_type** |  | [optional] 
**xss_protection** | **dict, none_type** |  | [optional] 
**certificate_transparency** | **dict, none_type** |  | [optional] 
**frame_options** | **dict, none_type** |  | [optional] 
**content_type_options** | **dict, none_type** |  | [optional] 
**permitted_cross_domain_policies** | **dict, none_type** |  | [optional] 
**coep** | **dict, none_type** |  | [optional] 
**coop** | **dict, none_type** |  | [optional] 
**corp** | **dict, none_type** |  | [optional] 
**referrer_policy** | **dict, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


